from __future__ import print_function

from os import sys, path

sys.path.append(path.dirname(path.dirname(path.abspath(__file__))))

from log_symbols import LogSymbols

for symbol in LogSymbols:
    print(symbol.value, symbol.name.lower())



# -*- coding: utf-8 -*-
"""This module tests LogSymbol enum."""
import re
import unittest

from log_symbols import LogSymbols

from tests._utils import strip_ansi


class TestLogSymbols(unittest.TestCase):
    """Test LogSymbols enum for attribute values."""

    def test_symbols(self):
        """Test the symbols in LogSymbol enum."""
        self.assertTrue(
            strip_ansi(LogSymbols.SUCCESS.value) in ('✔', 'v')
        )

        self.assertTrue(
            strip_ansi(LogSymbols.INFO.value) in ('ℹ', '¡')
        )

        self.assertTrue(
            strip_ansi(LogSymbols.WARNING.value) in ('⚠', '!!')
        )

        self.assertTrue(
            strip_ansi(LogSymbols.ERROR.value) in ('✖', '×')
        )


if __name__ == '__main__':
    SUITE = unittest.TestLoader().loadTestsFromTestCase(TestLogSymbols)
    unittest.TextTestRunner(verbosity=2).run(SUITE)



import sys

from setuptools import setup, find_packages  # pylint: disable=no-name-in-module,import-error

def dependencies(file):
    with open(file) as f:
        return f.read().splitlines()


setup(
    name='log_symbols',
    packages=find_packages(exclude=('tests', 'examples')),
    version='0.0.14',
    license='MIT',
    description='Colored symbols for various log levels for Python',
    long_description='Colored symbols for various log levels for Python. Find the documentation here: https://github.com/manrajgrover/py-log-symbols.',
    author='Manraj Singh',
    author_email='manrajsinghgrover@gmail.com',
    url='https://github.com/manrajgrover/py-log-symbols',
    keywords=[
        'log symbols',
        'symbols',
        'log'
    ],
    install_requires=dependencies('requirements.txt'),   
    extras_require={
        ':python_version < "3.4"': [
            'enum34==1.1.6',
        ],
    },
    tests_require=dependencies('requirements-dev.txt'),
    include_package_data=True
)



"""Utilities for tests.
"""

import re

def strip_ansi(string):
    """Strip ANSI encoding from given string.

    Parameters
    ----------
    string : str
        String from which encoding needs to be removed

    Returns
    -------
    str
        Encoding free string
    """
    pattern = r'(\x1b\[|\x9b)[^@-_]*[@-_]|\x1b[@-_]'
    return re.sub(pattern, '', string, flags=re.I)
